import os

import frontmatter

ingredients_foods = [
    "/Users/mtm/Documents/Obsidian Vault/beef bouillon.md",
    "/Users/mtm/Documents/Obsidian Vault/couscous.md",
    "/Users/mtm/Documents/Obsidian Vault/Dino Kale.md",
    "/Users/mtm/Documents/Obsidian Vault/dried cranberries.md",
    "/Users/mtm/Documents/Obsidian Vault/extra virgin olive oil.md",
    "/Users/mtm/Documents/Obsidian Vault/Farro Wheat.md",
    "/Users/mtm/Documents/Obsidian Vault/Farro Wheat.sync-conflict-20240315-221725-G6QCYAQ.md",
    "/Users/mtm/Documents/Obsidian Vault/Green Beans.md",
    "/Users/mtm/Documents/Obsidian Vault/Green Chili.md",
    "/Users/mtm/Documents/Obsidian Vault/Lemon.md",
    "/Users/mtm/Documents/Obsidian Vault/Lime.md",
    "/Users/mtm/Documents/Obsidian Vault/Medjool dates.md",
    "/Users/mtm/Documents/Obsidian Vault/Organic Russet Potato.md",
    "/Users/mtm/Documents/Obsidian Vault/pecans.md",
    "/Users/mtm/Documents/Obsidian Vault/potato starch.md",
    "/Users/mtm/Documents/Obsidian Vault/Red Potatoes.md",
    "/Users/mtm/Documents/Obsidian Vault/Seafood Mushroom.md",
    "/Users/mtm/Documents/Obsidian Vault/Yukon Gold Potato.md",
]

for file_path in ingredients_foods:
    with open(file_path, "r", encoding="utf-8") as file:
        content = file.read()
        post = frontmatter.loads(content)

    if "filetype" not in post.metadata:
        post.metadata["filetype"] = "product"
        new_content = frontmatter.dumps(post)

        with open(file_path, "w", encoding="utf-8") as file:
            file.write(new_content)

    print(f"Processed: {os.path.basename(file_path)}")



import logging

from . import add_sections, cli, log

__project_name__ = "itshire"


def main() -> int:
    args = cli.parse_args()
    log.configure_logging(args.verbose)
    logging.debug("fart")

    if args.command == "addstores":
        add_sections.main()
    else:
        print("hello")

    return 0



import os

import frontmatter

with open("filelist.txt", "r") as file:
    ingredients_foods = [line.strip() for line in file]

for file_path in ingredients_foods:
    with open(file_path, "r", encoding="utf-8") as file:
        content = file.read()
        post = frontmatter.loads(content)

    if "filetype" not in post.metadata:
        post.metadata["filetype"] = "product"
        new_content = frontmatter.dumps(post)

        with open(file_path, "w", encoding="utf-8") as file:
            file.write(new_content)

    print(f"Processed: {os.path.basename(file_path)}")



import hashlib
import logging
import pathlib
import sys

import mistletoe


def extract_headers(file_path):
    with open(file_path, "r") as file:
        markdown_content = file.read()
    parsed_markdown = mistletoe.Document(markdown_content)
    headers = []

    def _traverse(node):
        if isinstance(node, mistletoe.block_token.Heading):
            header_text = "".join(_extract_text(child) for child in node.children)
            headers.append(header_text.strip())
        for child in getattr(node, "children", []):
            _traverse(child)

    def _extract_text(node):
        if isinstance(node, mistletoe.span_token.RawText):
            return node.content
        elif isinstance(node, mistletoe.span_token.InlineCode):
            return node.children[0].content
        else:
            return "".join(_extract_text(child) for child in node.children)

    _traverse(parsed_markdown)
    return headers


def add_sections(file_path, section_names):
    with open(file_path, "r") as file:
        markdown_content = file.read()
    original_checksum = hashlib.md5(markdown_content.encode("utf-8")).hexdigest()

    for section_name in section_names:
        if section_name not in markdown_content:
            markdown_content += f"\n## [[{section_name}]]\n- [x] shopping\n"

    modified_checksum = hashlib.md5(markdown_content.encode("utf-8")).hexdigest()

    if original_checksum != modified_checksum:
        with open(file_path, "w") as file:
            file.write(markdown_content)


def main():
    file_paths = [line.strip() for line in sys.stdin if line.strip()]
    file_paths = [pathlib.Path(s) for s in file_paths]
    logging.debug(file_paths)
    stores = [
        "Central Co-op",
        "Hau Hau Market",
        "M2M",
        "PCC",
        "Safeway",
        "Trader Joes",
        "Uwajimaya",
    ]

    for file_path in file_paths:
        logging.info(f"file path: {file_path.absolute()}")
        existing_headers = extract_headers(file_path)
        missing_sections = [
            store_name for store_name in stores if store_name not in existing_headers
        ]
        if missing_sections:
            add_sections(file_path, missing_sections)

    print("Sections added successfully.")


if __name__ == "__main__":
    main()



import argparse


def parse_args():
    parser = argparse.ArgumentParser(description="Add sections to markdown files.")
    parser.add_argument(
        "-v", "--verbose", action="store_true", help="Enable verbose output"
    )

    subparsers = parser.add_subparsers(dest="command")

    addstores_parser = subparsers.add_parser(
        "addstores", help="Add stores as sections to markdown files from stdin"
    )
    addstores_parser.add_argument(
        "-v", "--verbose", action="store_true", help="Enable verbose output"
    )

    args = parser.parse_args()
    return args
